@@ -5,7 +5,7 @@
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="575"/>
+        <location filename="../datetime.cpp" line="580"/>
         <source>MX Date &amp; Time</source>
         <translation type="unfinished"></translation>
     </message>
@@ -30,65 +30,72 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="127"/>
-        <source>Date &amp; Time</source>
+        <location filename="../datetime.ui" line="124"/>
+        <source>Date &amp;&amp; Time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="195"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="281"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="282"/>
+        <location filename="../datetime.cpp" line="286"/>
         <source>Hardware Clock</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="287"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="293"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="296"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="316"/>
+        <location filename="../datetime.ui" line="313"/>
         <source>Time transfer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="322"/>
+        <location filename="../datetime.ui" line="319"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="325"/>
+        <location filename="../datetime.ui" line="322"/>
         <source>System Clock to Hardware Clock</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="332"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="335"/>
+        <location filename="../datetime.ui" line="332"/>
         <source>Hardware Clock to System Clock</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="345"/>
+        <location filename="../datetime.ui" line="342"/>
         <source>Time zone for the Hardware Clock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../datetime.ui" line="348"/>
+        <source>Local time</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../datetime.ui" line="351"/>
         <source>Local</source>
@@ -165,74 +172,90 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="160"/>
+        <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="211"/>
+        <location filename="../datetime.cpp" line="282"/>
+        <location filename="../datetime.cpp" line="286"/>
+        <source>System Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../datetime.cpp" line="292"/>
+        <source>The %1 time was transferred to the %2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../datetime.cpp" line="295"/>
+        <source>The %1 time could not be transferred to the %2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../datetime.cpp" line="334"/>
         <source>Updating...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="218"/>
+        <location filename="../datetime.cpp" line="344"/>
         <source>The system clock was updated successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="220"/>
+        <location filename="../datetime.cpp" line="346"/>
         <source>The system clock could not be updated.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="222"/>
+        <location filename="../datetime.cpp" line="348"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="574"/>
+        <location filename="../datetime.cpp" line="579"/>
         <source>About MX Date &amp; Time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="575"/>
+        <location filename="../datetime.cpp" line="580"/>
         <source>Version: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="576"/>
+        <location filename="../datetime.cpp" line="581"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="578"/>
+        <location filename="../datetime.cpp" line="583"/>
         <source>Copyright (c) MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="579"/>
-        <location filename="../datetime.cpp" line="593"/>
+        <location filename="../datetime.cpp" line="584"/>
+        <location filename="../datetime.cpp" line="598"/>
         <source>License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="580"/>
+        <location filename="../datetime.cpp" line="585"/>
         <source>Changelog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="581"/>
+        <location filename="../datetime.cpp" line="586"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="607"/>
+        <location filename="../datetime.cpp" line="612"/>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="626"/>
-        <source>MX Date \&amp; Time Help</source>
+        <location filename="../datetime.cpp" line="630"/>
+        <source>MX Date &amp; Time Help</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
